==> icinga2_2.1.1.orig.tar.gz: icinga2-2.1.1/lib/base/visibility.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2014 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef VISIBILITY_H
#define VISIBILITY_H

#ifndef _WIN32
#	define I2_EXPORT __attribute__ ((visibility("default")))
#	define I2_IMPORT
#else /* _WIN32 */
#	define I2_EXPORT __declspec(dllexport)
#	define I2_IMPORT __declspec(dllimport)
#endif /* _WIN32 */

#endif /* VISIBILITY_H */

==> icinga2_2.4.1.orig.tar.gz: icinga2-2.4.1/lib/base/visibility.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef VISIBILITY_H
#define VISIBILITY_H

#ifndef _WIN32
#	define I2_EXPORT __attribute__ ((visibility("default")))
#	define I2_IMPORT
#else /* _WIN32 */
#	define I2_EXPORT __declspec(dllexport)
#	define I2_IMPORT __declspec(dllimport)
#endif /* _WIN32 */

#define TOKENPASTE(x, y) x ## y
#define TOKENPASTE2(x, y) TOKENPASTE(x, y)

#ifdef HAVE_COUNTER_MACRO
#	define UNIQUE_NAME(prefix) TOKENPASTE2(prefix, __COUNTER__)
#else /* HAVE_COUNTER_MACRO */
#	define UNIQUE_NAME(prefix) prefix
#endif /* HAVE_COUNTER_MACRO */

#endif /* VISIBILITY_H */
